# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.0
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _medequivalence
else:
    import _medequivalence

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator_medequivalence_module(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _medequivalence.delete_SwigPyIterator_medequivalence_module

    def value(self):
        return _medequivalence.SwigPyIterator_medequivalence_module_value(self)

    def incr(self, n=1):
        return _medequivalence.SwigPyIterator_medequivalence_module_incr(self, n)

    def decr(self, n=1):
        return _medequivalence.SwigPyIterator_medequivalence_module_decr(self, n)

    def distance(self, x):
        return _medequivalence.SwigPyIterator_medequivalence_module_distance(self, x)

    def equal(self, x):
        return _medequivalence.SwigPyIterator_medequivalence_module_equal(self, x)

    def copy(self):
        return _medequivalence.SwigPyIterator_medequivalence_module_copy(self)

    def next(self):
        return _medequivalence.SwigPyIterator_medequivalence_module_next(self)

    def __next__(self):
        return _medequivalence.SwigPyIterator_medequivalence_module___next__(self)

    def previous(self):
        return _medequivalence.SwigPyIterator_medequivalence_module_previous(self)

    def advance(self, n):
        return _medequivalence.SwigPyIterator_medequivalence_module_advance(self, n)

    def __eq__(self, x):
        return _medequivalence.SwigPyIterator_medequivalence_module___eq__(self, x)

    def __ne__(self, x):
        return _medequivalence.SwigPyIterator_medequivalence_module___ne__(self, x)

    def __iadd__(self, n):
        return _medequivalence.SwigPyIterator_medequivalence_module___iadd__(self, n)

    def __isub__(self, n):
        return _medequivalence.SwigPyIterator_medequivalence_module___isub__(self, n)

    def __add__(self, n):
        return _medequivalence.SwigPyIterator_medequivalence_module___add__(self, n)

    def __sub__(self, *args):
        return _medequivalence.SwigPyIterator_medequivalence_module___sub__(self, *args)
    def __iter__(self): return self
    def __iter__(self):
        return self

# Register SwigPyIterator_medequivalence_module in _medequivalence:
_medequivalence.SwigPyIterator_medequivalence_module_swigregister(SwigPyIterator_medequivalence_module)
HAVE_CC_C99 = _medequivalence.HAVE_CC_C99
HAVE_CUSERID = _medequivalence.HAVE_CUSERID
HAVE_DLFCN_H = _medequivalence.HAVE_DLFCN_H
HAVE_FTIME = _medequivalence.HAVE_FTIME
HAVE_GETEUID = _medequivalence.HAVE_GETEUID
HAVE_GETPWUID = _medequivalence.HAVE_GETPWUID
HAVE_GETTIMEOFDAY = _medequivalence.HAVE_GETTIMEOFDAY
HAVE_H5PUBLIC_H = _medequivalence.HAVE_H5PUBLIC_H
HAVE_INT64 = _medequivalence.HAVE_INT64
HAVE_INTTYPES_H = _medequivalence.HAVE_INTTYPES_H
HAVE_MALLOC_H = _medequivalence.HAVE_MALLOC_H
HAVE_PWD_H = _medequivalence.HAVE_PWD_H
HAVE_STDBOOL_H = _medequivalence.HAVE_STDBOOL_H
HAVE_STDINT_H = _medequivalence.HAVE_STDINT_H
HAVE_STDIO_H = _medequivalence.HAVE_STDIO_H
HAVE_STDLIB_H = _medequivalence.HAVE_STDLIB_H
HAVE_STRINGS_H = _medequivalence.HAVE_STRINGS_H
HAVE_STRING_H = _medequivalence.HAVE_STRING_H
HAVE_SYS_STAT_H = _medequivalence.HAVE_SYS_STAT_H
HAVE_SYS_TIMEB_H = _medequivalence.HAVE_SYS_TIMEB_H
HAVE_SYS_TIME_H = _medequivalence.HAVE_SYS_TIME_H
HAVE_SYS_TYPES_H = _medequivalence.HAVE_SYS_TYPES_H
HAVE_UNISTD_H = _medequivalence.HAVE_UNISTD_H
HAVE__BOOL = _medequivalence.HAVE__BOOL
MED_CHECK_23FORMAT = _medequivalence.MED_CHECK_23FORMAT
MED_HAVE_FORTRAN = _medequivalence.MED_HAVE_FORTRAN
MESGERR = _medequivalence.MESGERR
PACKAGE = _medequivalence.PACKAGE
PACKAGE_BUGREPORT = _medequivalence.PACKAGE_BUGREPORT
PACKAGE_NAME = _medequivalence.PACKAGE_NAME
PACKAGE_STRING = _medequivalence.PACKAGE_STRING
PACKAGE_URL = _medequivalence.PACKAGE_URL
PACKAGE_VERSION = _medequivalence.PACKAGE_VERSION
SIZEOF_FORTRAN_INTEGER = _medequivalence.SIZEOF_FORTRAN_INTEGER
SIZEOF_INT = _medequivalence.SIZEOF_INT
SIZEOF_LONG = _medequivalence.SIZEOF_LONG
STDC_HEADERS = _medequivalence.STDC_HEADERS
VERSION = _medequivalence.VERSION
HDF_VERSION_REF = _medequivalence.HDF_VERSION_REF
HDF_VERSION_MAJOR_REF = _medequivalence.HDF_VERSION_MAJOR_REF
HDF_VERSION_MINOR_REF = _medequivalence.HDF_VERSION_MINOR_REF
HDF_VERSION_RELEASE_REF = _medequivalence.HDF_VERSION_RELEASE_REF
HDF_VERSION_NUM_REF = _medequivalence.HDF_VERSION_NUM_REF
H5F_LIBVER_18 = _medequivalence.H5F_LIBVER_18
MED_MAJOR_NUM = _medequivalence.MED_MAJOR_NUM
MED_MINOR_NUM = _medequivalence.MED_MINOR_NUM
MED_RELEASE_NUM = _medequivalence.MED_RELEASE_NUM
MED_3_LATEST_MINOR = _medequivalence.MED_3_LATEST_MINOR
MED_4_LATEST_MINOR = _medequivalence.MED_4_LATEST_MINOR
MED_5_LATEST_MINOR = _medequivalence.MED_5_LATEST_MINOR
MED_50_LATEST_RELEASE = _medequivalence.MED_50_LATEST_RELEASE
MED_NUM_MAJEUR = _medequivalence.MED_NUM_MAJEUR
MED_NUM_MINEUR = _medequivalence.MED_NUM_MINEUR
MED_NUM_RELEASE = _medequivalence.MED_NUM_RELEASE
MED_VERSION_STR = _medequivalence.MED_VERSION_STR
MED_MAX_PARA = _medequivalence.MED_MAX_PARA
MED_COMMENT_SIZE = _medequivalence.MED_COMMENT_SIZE
MED_IDENT_SIZE = _medequivalence.MED_IDENT_SIZE
MED_NAME_SIZE = _medequivalence.MED_NAME_SIZE
MED_SNAME_SIZE = _medequivalence.MED_SNAME_SIZE
MED_LNAME_SIZE = _medequivalence.MED_LNAME_SIZE
MED_SNAME_BLANK = _medequivalence.MED_SNAME_BLANK
MED_NAME_BLANK = _medequivalence.MED_NAME_BLANK
MED_PATHNAME_SIZE = _medequivalence.MED_PATHNAME_SIZE
MED_MAX_CHFID_PATH = _medequivalence.MED_MAX_CHFID_PATH
MED_FULL_INTERLACE = _medequivalence.MED_FULL_INTERLACE
MED_NO_INTERLACE = _medequivalence.MED_NO_INTERLACE
MED_UNDEF_INTERLACE = _medequivalence.MED_UNDEF_INTERLACE
MED_UNDEF_STMODE = _medequivalence.MED_UNDEF_STMODE
MED_GLOBAL_STMODE = _medequivalence.MED_GLOBAL_STMODE
MED_COMPACT_STMODE = _medequivalence.MED_COMPACT_STMODE
MED_GLOBAL_PFLMODE = _medequivalence.MED_GLOBAL_PFLMODE
MED_COMPACT_PFLMODE = _medequivalence.MED_COMPACT_PFLMODE
MED_UNDEF_PFLMODE = _medequivalence.MED_UNDEF_PFLMODE
MED_ACC_RDONLY = _medequivalence.MED_ACC_RDONLY
MED_ACC_RDWR = _medequivalence.MED_ACC_RDWR
MED_ACC_RDEXT = _medequivalence.MED_ACC_RDEXT
MED_ACC_CREAT = _medequivalence.MED_ACC_CREAT
MED_ACC_UNDEF = _medequivalence.MED_ACC_UNDEF
MED_UNSTRUCTURED_MESH = _medequivalence.MED_UNSTRUCTURED_MESH
MED_STRUCTURED_MESH = _medequivalence.MED_STRUCTURED_MESH
MED_UNDEF_MESH_TYPE = _medequivalence.MED_UNDEF_MESH_TYPE
MED_CARTESIAN_GRID = _medequivalence.MED_CARTESIAN_GRID
MED_POLAR_GRID = _medequivalence.MED_POLAR_GRID
MED_CURVILINEAR_GRID = _medequivalence.MED_CURVILINEAR_GRID
MED_UNDEF_GRID_TYPE = _medequivalence.MED_UNDEF_GRID_TYPE
MED_CELL = _medequivalence.MED_CELL
MED_DESCENDING_FACE = _medequivalence.MED_DESCENDING_FACE
MED_DESCENDING_EDGE = _medequivalence.MED_DESCENDING_EDGE
MED_NODE = _medequivalence.MED_NODE
MED_NODE_ELEMENT = _medequivalence.MED_NODE_ELEMENT
MED_STRUCT_ELEMENT = _medequivalence.MED_STRUCT_ELEMENT
MED_ALL_ENTITY_TYPE = _medequivalence.MED_ALL_ENTITY_TYPE
MED_UNDEF_ENTITY_TYPE = _medequivalence.MED_UNDEF_ENTITY_TYPE
MED_N_ENTITY_TYPES = _medequivalence.MED_N_ENTITY_TYPES
MED_COORDINATE = _medequivalence.MED_COORDINATE
MED_CONNECTIVITY = _medequivalence.MED_CONNECTIVITY
MED_NAME = _medequivalence.MED_NAME
MED_NUMBER = _medequivalence.MED_NUMBER
MED_FAMILY_NUMBER = _medequivalence.MED_FAMILY_NUMBER
MED_COORDINATE_AXIS1 = _medequivalence.MED_COORDINATE_AXIS1
MED_COORDINATE_AXIS2 = _medequivalence.MED_COORDINATE_AXIS2
MED_COORDINATE_AXIS3 = _medequivalence.MED_COORDINATE_AXIS3
MED_INDEX_FACE = _medequivalence.MED_INDEX_FACE
MED_INDEX_NODE = _medequivalence.MED_INDEX_NODE
MED_GLOBAL_NUMBER = _medequivalence.MED_GLOBAL_NUMBER
MED_VARIABLE_ATTRIBUTE = _medequivalence.MED_VARIABLE_ATTRIBUTE
MED_COORDINATE_TRSF = _medequivalence.MED_COORDINATE_TRSF
MED_UNDEF_DATATYPE = _medequivalence.MED_UNDEF_DATATYPE
MED_INTERNAL_FLOAT32 = _medequivalence.MED_INTERNAL_FLOAT32
MED_INTERNAL_FLOAT64 = _medequivalence.MED_INTERNAL_FLOAT64
MED_INTERNAL_INT8 = _medequivalence.MED_INTERNAL_INT8
MED_INTERNAL_INT32 = _medequivalence.MED_INTERNAL_INT32
MED_INTERNAL_INT64 = _medequivalence.MED_INTERNAL_INT64
MED_INTERNAL_INT = _medequivalence.MED_INTERNAL_INT
MED_INTERNAL_NAME = _medequivalence.MED_INTERNAL_NAME
MED_INTERNAL_SNAME = _medequivalence.MED_INTERNAL_SNAME
MED_INTERNAL_LNAME = _medequivalence.MED_INTERNAL_LNAME
MED_INTERNAL_IDENT = _medequivalence.MED_INTERNAL_IDENT
MED_INTERNAL_CHAR = _medequivalence.MED_INTERNAL_CHAR
MED_INTERNAL_UNDEF = _medequivalence.MED_INTERNAL_UNDEF
MED_DOUBLE = _medequivalence.MED_DOUBLE
MED_FLOAT64 = _medequivalence.MED_FLOAT64
MED_FLOAT32 = _medequivalence.MED_FLOAT32
MED_INT32 = _medequivalence.MED_INT32
MED_INT64 = _medequivalence.MED_INT64
MED_INT = _medequivalence.MED_INT
MED_ATT_FLOAT64 = _medequivalence.MED_ATT_FLOAT64
MED_ATT_INT = _medequivalence.MED_ATT_INT
MED_ATT_NAME = _medequivalence.MED_ATT_NAME
MED_ATT_UNDEF = _medequivalence.MED_ATT_UNDEF
MED_MESH = _medequivalence.MED_MESH
MED_FIELD = _medequivalence.MED_FIELD
MED_LIBRARY = _medequivalence.MED_LIBRARY
MED_FILE = _medequivalence.MED_FILE
MED_MESH_SUPPORT = _medequivalence.MED_MESH_SUPPORT
MED_ELSTRUCT = _medequivalence.MED_ELSTRUCT
MED_FAMILY = _medequivalence.MED_FAMILY
MED_EQUIVALENCE = _medequivalence.MED_EQUIVALENCE
MED_GROUP = _medequivalence.MED_GROUP
MED_JOINT = _medequivalence.MED_JOINT
MED_LOCALIZATION = _medequivalence.MED_LOCALIZATION
MED_PROFILE = _medequivalence.MED_PROFILE
MED_FILTER = _medequivalence.MED_FILTER
MED_INTERPOLATION = _medequivalence.MED_INTERPOLATION
MED_NUMERICAL_DATA = _medequivalence.MED_NUMERICAL_DATA
MED_LINK = _medequivalence.MED_LINK
MED_CLASS_UNDEF = _medequivalence.MED_CLASS_UNDEF
MED_CLASS_ALL = _medequivalence.MED_CLASS_ALL
MED_POINT1 = _medequivalence.MED_POINT1
MED_SEG2 = _medequivalence.MED_SEG2
MED_SEG3 = _medequivalence.MED_SEG3
MED_SEG4 = _medequivalence.MED_SEG4
MED_TRIA3 = _medequivalence.MED_TRIA3
MED_QUAD4 = _medequivalence.MED_QUAD4
MED_TRIA6 = _medequivalence.MED_TRIA6
MED_TRIA7 = _medequivalence.MED_TRIA7
MED_QUAD8 = _medequivalence.MED_QUAD8
MED_QUAD9 = _medequivalence.MED_QUAD9
MED_TETRA4 = _medequivalence.MED_TETRA4
MED_PYRA5 = _medequivalence.MED_PYRA5
MED_PENTA6 = _medequivalence.MED_PENTA6
MED_HEXA8 = _medequivalence.MED_HEXA8
MED_TETRA10 = _medequivalence.MED_TETRA10
MED_OCTA12 = _medequivalence.MED_OCTA12
MED_PYRA13 = _medequivalence.MED_PYRA13
MED_PENTA15 = _medequivalence.MED_PENTA15
MED_PENTA18 = _medequivalence.MED_PENTA18
MED_HEXA20 = _medequivalence.MED_HEXA20
MED_HEXA27 = _medequivalence.MED_HEXA27
MED_POLYGON = _medequivalence.MED_POLYGON
MED_POLYGON2 = _medequivalence.MED_POLYGON2
MED_POLYHEDRON = _medequivalence.MED_POLYHEDRON
MED_STRUCT_GEO_INTERNAL = _medequivalence.MED_STRUCT_GEO_INTERNAL
MED_STRUCT_GEO_SUP_INTERNAL = _medequivalence.MED_STRUCT_GEO_SUP_INTERNAL
MED_NONE = _medequivalence.MED_NONE
MED_NO_GEOTYPE = _medequivalence.MED_NO_GEOTYPE
MED_UNDEF_GEOTYPE = _medequivalence.MED_UNDEF_GEOTYPE
MED_UNDEF_GEOMETRY_TYPE = _medequivalence.MED_UNDEF_GEOMETRY_TYPE
MED_ALL_GEOTYPE = _medequivalence.MED_ALL_GEOTYPE
MED_GEO_ALL = _medequivalence.MED_GEO_ALL
MED_N_CELL_GEO = _medequivalence.MED_N_CELL_GEO
MED_N_CELL_FIXED_GEO = _medequivalence.MED_N_CELL_FIXED_GEO
MED_N_CELL_GEO_FIXED_CON = _medequivalence.MED_N_CELL_GEO_FIXED_CON
MED_N_FACE_GEO = _medequivalence.MED_N_FACE_GEO
MED_N_FACE_FIXED_GEO = _medequivalence.MED_N_FACE_FIXED_GEO
MED_N_FACE_GEO_FIXED_CON = _medequivalence.MED_N_FACE_GEO_FIXED_CON
MED_N_EDGE_TYPES = _medequivalence.MED_N_EDGE_TYPES
MED_N_EDGE_FIXED_GEO = _medequivalence.MED_N_EDGE_FIXED_GEO
MED_N_EDGE_GEO_FIXED_CON = _medequivalence.MED_N_EDGE_GEO_FIXED_CON
MED_N_NODE_GEO = _medequivalence.MED_N_NODE_GEO
MED_N_NODE_FIXED_GEO = _medequivalence.MED_N_NODE_FIXED_GEO
MED_N_NODE_GEO_FIXED_CON = _medequivalence.MED_N_NODE_GEO_FIXED_CON
MED_NODAL = _medequivalence.MED_NODAL
MED_DESCENDING = _medequivalence.MED_DESCENDING
MED_UNDEF_CONNECTIVITY_MODE = _medequivalence.MED_UNDEF_CONNECTIVITY_MODE
MED_NO_CMODE = _medequivalence.MED_NO_CMODE
MED_CARTESIAN = _medequivalence.MED_CARTESIAN
MED_CYLINDRICAL = _medequivalence.MED_CYLINDRICAL
MED_SPHERICAL = _medequivalence.MED_SPHERICAL
MED_UNDEF_AXIS_TYPE = _medequivalence.MED_UNDEF_AXIS_TYPE
MED_FALSE = _medequivalence.MED_FALSE
MED_TRUE = _medequivalence.MED_TRUE
MED_GAUSS_ELNO = _medequivalence.MED_GAUSS_ELNO
MED_IPOINT_ELNO = _medequivalence.MED_IPOINT_ELNO
MED_NO_NAME = _medequivalence.MED_NO_NAME
MED_NO_MESHNAME = _medequivalence.MED_NO_MESHNAME
MED_NO_MESH = _medequivalence.MED_NO_MESH
MED_NO_MESH_SUPPORT = _medequivalence.MED_NO_MESH_SUPPORT
MED_NO_LOCALIZATION = _medequivalence.MED_NO_LOCALIZATION
MED_NO_INTERPOLATION = _medequivalence.MED_NO_INTERPOLATION
MED_NO_IPOINT_INTERNAL = _medequivalence.MED_NO_IPOINT_INTERNAL
MED_NO_PROFILE = _medequivalence.MED_NO_PROFILE
MED_NO_GROUP = _medequivalence.MED_NO_GROUP
MED_ALLENTITIES_PROFILE = _medequivalence.MED_ALLENTITIES_PROFILE
MED_NO_PROFILE_INTERNAL = _medequivalence.MED_NO_PROFILE_INTERNAL
MED_SAME_PROFILE_INTERNAL = _medequivalence.MED_SAME_PROFILE_INTERNAL
MED_ALL_CONSTITUENT = _medequivalence.MED_ALL_CONSTITUENT
MED_UNDEF_SIZE = _medequivalence.MED_UNDEF_SIZE
MED_NO_PROFILE_SIZE = _medequivalence.MED_NO_PROFILE_SIZE
MED_SORT_DTIT = _medequivalence.MED_SORT_DTIT
MED_SORT_ITDT = _medequivalence.MED_SORT_ITDT
MED_SORT_UNDEF = _medequivalence.MED_SORT_UNDEF
MED_ALL_DT = _medequivalence.MED_ALL_DT
MED_ALL_IT = _medequivalence.MED_ALL_IT
MED_NO_DT = _medequivalence.MED_NO_DT
MED_NO_IT = _medequivalence.MED_NO_IT
MED_UNDEF_DT = _medequivalence.MED_UNDEF_DT
MED_ATT_NOT_FILLED = _medequivalence.MED_ATT_NOT_FILLED
MED_MAX_FILTER_SPACES = _medequivalence.MED_MAX_FILTER_SPACES
class med_filter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    nspaces = property(_medequivalence.med_filter_nspaces_get, _medequivalence.med_filter_nspaces_set)
    memspace = property(_medequivalence.med_filter_memspace_get, _medequivalence.med_filter_memspace_set)
    diskspace = property(_medequivalence.med_filter_diskspace_get, _medequivalence.med_filter_diskspace_set)
    nentity = property(_medequivalence.med_filter_nentity_get, _medequivalence.med_filter_nentity_set)
    nvaluesperentity = property(_medequivalence.med_filter_nvaluesperentity_get, _medequivalence.med_filter_nvaluesperentity_set)
    nconstituentpervalue = property(_medequivalence.med_filter_nconstituentpervalue_get, _medequivalence.med_filter_nconstituentpervalue_set)
    constituentselect = property(_medequivalence.med_filter_constituentselect_get, _medequivalence.med_filter_constituentselect_set)
    switchmode = property(_medequivalence.med_filter_switchmode_get, _medequivalence.med_filter_switchmode_set)
    filterarraysize = property(_medequivalence.med_filter_filterarraysize_get, _medequivalence.med_filter_filterarraysize_set)
    filterarray23v30 = property(_medequivalence.med_filter_filterarray23v30_get, _medequivalence.med_filter_filterarray23v30_set)
    profilearraysize = property(_medequivalence.med_filter_profilearraysize_get, _medequivalence.med_filter_profilearraysize_set)
    storagemode = property(_medequivalence.med_filter_storagemode_get, _medequivalence.med_filter_storagemode_set)
    profilename = property(_medequivalence.med_filter_profilename_get, _medequivalence.med_filter_profilename_set)

    def __init__(self):
        r"""__init__(self) -> med_filter"""
        _medequivalence.med_filter_swiginit(self, _medequivalence.new_med_filter())
    __swig_destroy__ = _medequivalence.delete_med_filter

# Register med_filter in _medequivalence:
_medequivalence.med_filter_swigregister(med_filter)
MED_NO_FILTER_SIZE = _medequivalence.MED_NO_FILTER_SIZE
MED_NO_PROFILE_F = _medequivalence.MED_NO_PROFILE_F
class med_file_version(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    majeur = property(_medequivalence.med_file_version_majeur_get, _medequivalence.med_file_version_majeur_set)
    mineur = property(_medequivalence.med_file_version_mineur_get, _medequivalence.med_file_version_mineur_set)
    release = property(_medequivalence.med_file_version_release_get, _medequivalence.med_file_version_release_set)

    def __init__(self):
        r"""__init__(self) -> med_file_version"""
        _medequivalence.med_file_version_swiginit(self, _medequivalence.new_med_file_version())
    __swig_destroy__ = _medequivalence.delete_med_file_version

# Register med_file_version in _medequivalence:
_medequivalence.med_file_version_swigregister(med_file_version)
class med_memfile(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    app_image_ptr = property(_medequivalence.med_memfile_app_image_ptr_get, _medequivalence.med_memfile_app_image_ptr_set)
    app_image_size = property(_medequivalence.med_memfile_app_image_size_get, _medequivalence.med_memfile_app_image_size_set)
    ref_count = property(_medequivalence.med_memfile_ref_count_get, _medequivalence.med_memfile_ref_count_set)
    fapl_image_ptr = property(_medequivalence.med_memfile_fapl_image_ptr_get, _medequivalence.med_memfile_fapl_image_ptr_set)
    fapl_image_size = property(_medequivalence.med_memfile_fapl_image_size_get, _medequivalence.med_memfile_fapl_image_size_set)
    fapl_ref_count = property(_medequivalence.med_memfile_fapl_ref_count_get, _medequivalence.med_memfile_fapl_ref_count_set)
    vfd_image_ptr = property(_medequivalence.med_memfile_vfd_image_ptr_get, _medequivalence.med_memfile_vfd_image_ptr_set)
    vfd_image_size = property(_medequivalence.med_memfile_vfd_image_size_get, _medequivalence.med_memfile_vfd_image_size_set)
    vfd_ref_count = property(_medequivalence.med_memfile_vfd_ref_count_get, _medequivalence.med_memfile_vfd_ref_count_set)
    flags = property(_medequivalence.med_memfile_flags_get, _medequivalence.med_memfile_flags_set)

    def __init__(self):
        r"""__init__(self) -> med_memfile"""
        _medequivalence.med_memfile_swiginit(self, _medequivalence.new_med_memfile())
    __swig_destroy__ = _medequivalence.delete_med_memfile

# Register med_memfile in _medequivalence:
_medequivalence.med_memfile_swigregister(med_memfile)

def MEDgetEntityTypeIt(entitytype):
    return _medequivalence.MEDgetEntityTypeIt(entitytype)

def MEDgetCellGeometryTypeIt(geotype):
    return _medequivalence.MEDgetCellGeometryTypeIt(geotype)

def MEDgetFaceGeometryTypeIt(geotype):
    return _medequivalence.MEDgetFaceGeometryTypeIt(geotype)

def MEDgetEdgeGeometryTypeIt(geotype):
    return _medequivalence.MEDgetEdgeGeometryTypeIt(geotype)

def MEDgetNodeGeometryTypeIt(geotype):
    return _medequivalence.MEDgetNodeGeometryTypeIt(geotype)

def MEDgetEntityGeometryTypeIt(entitytype, geotype):
    return _medequivalence.MEDgetEntityGeometryTypeIt(entitytype, geotype)

def MEDgetGeometryTypeName(geotype):
    return _medequivalence.MEDgetGeometryTypeName(geotype)

def MEDgetEntityTypeName(entitytype):
    return _medequivalence.MEDgetEntityTypeName(entitytype)
MED_PARTICLE_NAME = _medequivalence.MED_PARTICLE_NAME
MED_BALL_NAME = _medequivalence.MED_BALL_NAME
MED_BEAM_NAME = _medequivalence.MED_BEAM_NAME
MED_PARTICLE_LABEL = _medequivalence.MED_PARTICLE_LABEL
MED_BALL_DIAMETER = _medequivalence.MED_BALL_DIAMETER
MED_BEAM_THICKNESS = _medequivalence.MED_BEAM_THICKNESS
import med.medenum
class MEDBOOL(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medequivalence.MEDBOOL_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medequivalence.MEDBOOL___nonzero__(self)

    def __bool__(self):
        return _medequivalence.MEDBOOL___bool__(self)

    def __len__(self):
        return _medequivalence.MEDBOOL___len__(self)

    def __getslice__(self, i, j):
        return _medequivalence.MEDBOOL___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medequivalence.MEDBOOL___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medequivalence.MEDBOOL___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medequivalence.MEDBOOL___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medequivalence.MEDBOOL___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medequivalence.MEDBOOL___setitem__(self, *args)

    def pop(self):
        return _medequivalence.MEDBOOL_pop(self)

    def append(self, x):
        return _medequivalence.MEDBOOL_append(self, x)

    def empty(self):
        return _medequivalence.MEDBOOL_empty(self)

    def size(self):
        return _medequivalence.MEDBOOL_size(self)

    def swap(self, v):
        return _medequivalence.MEDBOOL_swap(self, v)

    def begin(self):
        return _medequivalence.MEDBOOL_begin(self)

    def end(self):
        return _medequivalence.MEDBOOL_end(self)

    def rbegin(self):
        return _medequivalence.MEDBOOL_rbegin(self)

    def rend(self):
        return _medequivalence.MEDBOOL_rend(self)

    def clear(self):
        return _medequivalence.MEDBOOL_clear(self)

    def get_allocator(self):
        return _medequivalence.MEDBOOL_get_allocator(self)

    def pop_back(self):
        return _medequivalence.MEDBOOL_pop_back(self)

    def erase(self, *args):
        return _medequivalence.MEDBOOL_erase(self, *args)

    def __init__(self, *args):
        _medequivalence.MEDBOOL_swiginit(self, _medequivalence.new_MEDBOOL(*args))

    def push_back(self, x):
        return _medequivalence.MEDBOOL_push_back(self, x)

    def front(self):
        return _medequivalence.MEDBOOL_front(self)

    def back(self):
        return _medequivalence.MEDBOOL_back(self)

    def assign(self, n, x):
        return _medequivalence.MEDBOOL_assign(self, n, x)

    def resize(self, *args):
        return _medequivalence.MEDBOOL_resize(self, *args)

    def insert(self, *args):
        return _medequivalence.MEDBOOL_insert(self, *args)

    def reserve(self, n):
        return _medequivalence.MEDBOOL_reserve(self, n)

    def capacity(self):
        return _medequivalence.MEDBOOL_capacity(self)
    __swig_destroy__ = _medequivalence.delete_MEDBOOL

# Register MEDBOOL in _medequivalence:
_medequivalence.MEDBOOL_swigregister(MEDBOOL)
cvar = _medequivalence.cvar
MED_GET_ENTITY_TYPENAME = cvar.MED_GET_ENTITY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPENAME = cvar.MED_GET_CELL_GEOMETRY_TYPENAME
MED_GET_FACE_GEOMETRY_TYPENAME = cvar.MED_GET_FACE_GEOMETRY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE = cvar.MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE
MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT = cvar.MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT


MEDBOOL.__str__= lambda self: str([x for x in self])
MEDBOOL.__repr__= lambda self: "MEDBOOL("+str([x for x in self])+")"

class MEDFLOAT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medequivalence.MEDFLOAT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medequivalence.MEDFLOAT___nonzero__(self)

    def __bool__(self):
        return _medequivalence.MEDFLOAT___bool__(self)

    def __len__(self):
        return _medequivalence.MEDFLOAT___len__(self)

    def __getslice__(self, i, j):
        return _medequivalence.MEDFLOAT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medequivalence.MEDFLOAT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medequivalence.MEDFLOAT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medequivalence.MEDFLOAT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medequivalence.MEDFLOAT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medequivalence.MEDFLOAT___setitem__(self, *args)

    def pop(self):
        return _medequivalence.MEDFLOAT_pop(self)

    def append(self, x):
        return _medequivalence.MEDFLOAT_append(self, x)

    def empty(self):
        return _medequivalence.MEDFLOAT_empty(self)

    def size(self):
        return _medequivalence.MEDFLOAT_size(self)

    def swap(self, v):
        return _medequivalence.MEDFLOAT_swap(self, v)

    def begin(self):
        return _medequivalence.MEDFLOAT_begin(self)

    def end(self):
        return _medequivalence.MEDFLOAT_end(self)

    def rbegin(self):
        return _medequivalence.MEDFLOAT_rbegin(self)

    def rend(self):
        return _medequivalence.MEDFLOAT_rend(self)

    def clear(self):
        return _medequivalence.MEDFLOAT_clear(self)

    def get_allocator(self):
        return _medequivalence.MEDFLOAT_get_allocator(self)

    def pop_back(self):
        return _medequivalence.MEDFLOAT_pop_back(self)

    def erase(self, *args):
        return _medequivalence.MEDFLOAT_erase(self, *args)

    def __init__(self, *args):
        _medequivalence.MEDFLOAT_swiginit(self, _medequivalence.new_MEDFLOAT(*args))

    def push_back(self, x):
        return _medequivalence.MEDFLOAT_push_back(self, x)

    def front(self):
        return _medequivalence.MEDFLOAT_front(self)

    def back(self):
        return _medequivalence.MEDFLOAT_back(self)

    def assign(self, n, x):
        return _medequivalence.MEDFLOAT_assign(self, n, x)

    def resize(self, *args):
        return _medequivalence.MEDFLOAT_resize(self, *args)

    def insert(self, *args):
        return _medequivalence.MEDFLOAT_insert(self, *args)

    def reserve(self, n):
        return _medequivalence.MEDFLOAT_reserve(self, n)

    def capacity(self):
        return _medequivalence.MEDFLOAT_capacity(self)

    def __iadd__(self, value):
        return _medequivalence.MEDFLOAT___iadd__(self, value)

    def __add__(self, value):
        return _medequivalence.MEDFLOAT___add__(self, value)

    def __isub__(self, value):
        return _medequivalence.MEDFLOAT___isub__(self, value)

    def __sub__(self, value):
        return _medequivalence.MEDFLOAT___sub__(self, value)

    def __imul__(self, value):
        return _medequivalence.MEDFLOAT___imul__(self, value)

    def __mul__(self, value):
        return _medequivalence.MEDFLOAT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medequivalence.MEDFLOAT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medequivalence.MEDFLOAT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medequivalence.MEDFLOAT___le__(self, value)

    def __lt__(self, value):
        return _medequivalence.MEDFLOAT___lt__(self, value)

    def __gt__(self, value):
        return _medequivalence.MEDFLOAT___gt__(self, value)

    def __ge__(self, value):
        return _medequivalence.MEDFLOAT___ge__(self, value)

    def __eq__(self, value):
        return _medequivalence.MEDFLOAT___eq__(self, value)

    def __ne__(self, value):
        return _medequivalence.MEDFLOAT___ne__(self, value)
    __swig_destroy__ = _medequivalence.delete_MEDFLOAT

# Register MEDFLOAT in _medequivalence:
_medequivalence.MEDFLOAT_swigregister(MEDFLOAT)

MEDFLOAT.__str__= lambda self: str([x for x in self])
MEDFLOAT.__repr__= lambda self:"MEDFLOAT" +"("+str([x for x in self])+")"


MEDFLOAT64=MEDFLOAT
MEDDOUBLE=MEDFLOAT

class MEDFLOAT32(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medequivalence.MEDFLOAT32_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medequivalence.MEDFLOAT32___nonzero__(self)

    def __bool__(self):
        return _medequivalence.MEDFLOAT32___bool__(self)

    def __len__(self):
        return _medequivalence.MEDFLOAT32___len__(self)

    def __getslice__(self, i, j):
        return _medequivalence.MEDFLOAT32___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medequivalence.MEDFLOAT32___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medequivalence.MEDFLOAT32___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medequivalence.MEDFLOAT32___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medequivalence.MEDFLOAT32___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medequivalence.MEDFLOAT32___setitem__(self, *args)

    def pop(self):
        return _medequivalence.MEDFLOAT32_pop(self)

    def append(self, x):
        return _medequivalence.MEDFLOAT32_append(self, x)

    def empty(self):
        return _medequivalence.MEDFLOAT32_empty(self)

    def size(self):
        return _medequivalence.MEDFLOAT32_size(self)

    def swap(self, v):
        return _medequivalence.MEDFLOAT32_swap(self, v)

    def begin(self):
        return _medequivalence.MEDFLOAT32_begin(self)

    def end(self):
        return _medequivalence.MEDFLOAT32_end(self)

    def rbegin(self):
        return _medequivalence.MEDFLOAT32_rbegin(self)

    def rend(self):
        return _medequivalence.MEDFLOAT32_rend(self)

    def clear(self):
        return _medequivalence.MEDFLOAT32_clear(self)

    def get_allocator(self):
        return _medequivalence.MEDFLOAT32_get_allocator(self)

    def pop_back(self):
        return _medequivalence.MEDFLOAT32_pop_back(self)

    def erase(self, *args):
        return _medequivalence.MEDFLOAT32_erase(self, *args)

    def __init__(self, *args):
        _medequivalence.MEDFLOAT32_swiginit(self, _medequivalence.new_MEDFLOAT32(*args))

    def push_back(self, x):
        return _medequivalence.MEDFLOAT32_push_back(self, x)

    def front(self):
        return _medequivalence.MEDFLOAT32_front(self)

    def back(self):
        return _medequivalence.MEDFLOAT32_back(self)

    def assign(self, n, x):
        return _medequivalence.MEDFLOAT32_assign(self, n, x)

    def resize(self, *args):
        return _medequivalence.MEDFLOAT32_resize(self, *args)

    def insert(self, *args):
        return _medequivalence.MEDFLOAT32_insert(self, *args)

    def reserve(self, n):
        return _medequivalence.MEDFLOAT32_reserve(self, n)

    def capacity(self):
        return _medequivalence.MEDFLOAT32_capacity(self)

    def __iadd__(self, value):
        return _medequivalence.MEDFLOAT32___iadd__(self, value)

    def __add__(self, value):
        return _medequivalence.MEDFLOAT32___add__(self, value)

    def __isub__(self, value):
        return _medequivalence.MEDFLOAT32___isub__(self, value)

    def __sub__(self, value):
        return _medequivalence.MEDFLOAT32___sub__(self, value)

    def __imul__(self, value):
        return _medequivalence.MEDFLOAT32___imul__(self, value)

    def __mul__(self, value):
        return _medequivalence.MEDFLOAT32___mul__(self, value)

    def __itruediv__(self, *args):
        return _medequivalence.MEDFLOAT32___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medequivalence.MEDFLOAT32___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medequivalence.MEDFLOAT32___le__(self, value)

    def __lt__(self, value):
        return _medequivalence.MEDFLOAT32___lt__(self, value)

    def __gt__(self, value):
        return _medequivalence.MEDFLOAT32___gt__(self, value)

    def __ge__(self, value):
        return _medequivalence.MEDFLOAT32___ge__(self, value)

    def __eq__(self, value):
        return _medequivalence.MEDFLOAT32___eq__(self, value)

    def __ne__(self, value):
        return _medequivalence.MEDFLOAT32___ne__(self, value)
    __swig_destroy__ = _medequivalence.delete_MEDFLOAT32

# Register MEDFLOAT32 in _medequivalence:
_medequivalence.MEDFLOAT32_swigregister(MEDFLOAT32)

MEDFLOAT32.__str__= lambda self: str([x for x in self])
MEDFLOAT32.__repr__= lambda self:"MEDFLOAT32" +"("+str([x for x in self])+")"

class MEDINT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medequivalence.MEDINT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medequivalence.MEDINT___nonzero__(self)

    def __bool__(self):
        return _medequivalence.MEDINT___bool__(self)

    def __len__(self):
        return _medequivalence.MEDINT___len__(self)

    def __getslice__(self, i, j):
        return _medequivalence.MEDINT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medequivalence.MEDINT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medequivalence.MEDINT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medequivalence.MEDINT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medequivalence.MEDINT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medequivalence.MEDINT___setitem__(self, *args)

    def pop(self):
        return _medequivalence.MEDINT_pop(self)

    def append(self, x):
        return _medequivalence.MEDINT_append(self, x)

    def empty(self):
        return _medequivalence.MEDINT_empty(self)

    def size(self):
        return _medequivalence.MEDINT_size(self)

    def swap(self, v):
        return _medequivalence.MEDINT_swap(self, v)

    def begin(self):
        return _medequivalence.MEDINT_begin(self)

    def end(self):
        return _medequivalence.MEDINT_end(self)

    def rbegin(self):
        return _medequivalence.MEDINT_rbegin(self)

    def rend(self):
        return _medequivalence.MEDINT_rend(self)

    def clear(self):
        return _medequivalence.MEDINT_clear(self)

    def get_allocator(self):
        return _medequivalence.MEDINT_get_allocator(self)

    def pop_back(self):
        return _medequivalence.MEDINT_pop_back(self)

    def erase(self, *args):
        return _medequivalence.MEDINT_erase(self, *args)

    def __init__(self, *args):
        _medequivalence.MEDINT_swiginit(self, _medequivalence.new_MEDINT(*args))

    def push_back(self, x):
        return _medequivalence.MEDINT_push_back(self, x)

    def front(self):
        return _medequivalence.MEDINT_front(self)

    def back(self):
        return _medequivalence.MEDINT_back(self)

    def assign(self, n, x):
        return _medequivalence.MEDINT_assign(self, n, x)

    def resize(self, *args):
        return _medequivalence.MEDINT_resize(self, *args)

    def insert(self, *args):
        return _medequivalence.MEDINT_insert(self, *args)

    def reserve(self, n):
        return _medequivalence.MEDINT_reserve(self, n)

    def capacity(self):
        return _medequivalence.MEDINT_capacity(self)

    def __iadd__(self, value):
        return _medequivalence.MEDINT___iadd__(self, value)

    def __add__(self, value):
        return _medequivalence.MEDINT___add__(self, value)

    def __isub__(self, value):
        return _medequivalence.MEDINT___isub__(self, value)

    def __sub__(self, value):
        return _medequivalence.MEDINT___sub__(self, value)

    def __imul__(self, value):
        return _medequivalence.MEDINT___imul__(self, value)

    def __mul__(self, value):
        return _medequivalence.MEDINT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medequivalence.MEDINT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medequivalence.MEDINT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medequivalence.MEDINT___le__(self, value)

    def __lt__(self, value):
        return _medequivalence.MEDINT___lt__(self, value)

    def __gt__(self, value):
        return _medequivalence.MEDINT___gt__(self, value)

    def __ge__(self, value):
        return _medequivalence.MEDINT___ge__(self, value)

    def __eq__(self, value):
        return _medequivalence.MEDINT___eq__(self, value)

    def __ne__(self, value):
        return _medequivalence.MEDINT___ne__(self, value)
    __swig_destroy__ = _medequivalence.delete_MEDINT

# Register MEDINT in _medequivalence:
_medequivalence.MEDINT_swigregister(MEDINT)

MEDINT.__str__= lambda self: str([x for x in self])
MEDINT.__repr__= lambda self:"MEDINT" +"("+str([x for x in self])+")"


MEDINT32=MEDINT


MEDINT64=None

class MEDCHAR(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medequivalence.MEDCHAR_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medequivalence.MEDCHAR___nonzero__(self)

    def __bool__(self):
        return _medequivalence.MEDCHAR___bool__(self)

    def __len__(self):
        return _medequivalence.MEDCHAR___len__(self)

    def __getslice__(self, i, j):
        return _medequivalence.MEDCHAR___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medequivalence.MEDCHAR___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medequivalence.MEDCHAR___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medequivalence.MEDCHAR___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medequivalence.MEDCHAR___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medequivalence.MEDCHAR___setitem__(self, *args)

    def pop(self):
        return _medequivalence.MEDCHAR_pop(self)

    def append(self, x):
        return _medequivalence.MEDCHAR_append(self, x)

    def empty(self):
        return _medequivalence.MEDCHAR_empty(self)

    def size(self):
        return _medequivalence.MEDCHAR_size(self)

    def swap(self, v):
        return _medequivalence.MEDCHAR_swap(self, v)

    def begin(self):
        return _medequivalence.MEDCHAR_begin(self)

    def end(self):
        return _medequivalence.MEDCHAR_end(self)

    def rbegin(self):
        return _medequivalence.MEDCHAR_rbegin(self)

    def rend(self):
        return _medequivalence.MEDCHAR_rend(self)

    def clear(self):
        return _medequivalence.MEDCHAR_clear(self)

    def get_allocator(self):
        return _medequivalence.MEDCHAR_get_allocator(self)

    def pop_back(self):
        return _medequivalence.MEDCHAR_pop_back(self)

    def erase(self, *args):
        return _medequivalence.MEDCHAR_erase(self, *args)

    def __init__(self, *args):
        _medequivalence.MEDCHAR_swiginit(self, _medequivalence.new_MEDCHAR(*args))

    def push_back(self, x):
        return _medequivalence.MEDCHAR_push_back(self, x)

    def front(self):
        return _medequivalence.MEDCHAR_front(self)

    def back(self):
        return _medequivalence.MEDCHAR_back(self)

    def assign(self, n, x):
        return _medequivalence.MEDCHAR_assign(self, n, x)

    def resize(self, *args):
        return _medequivalence.MEDCHAR_resize(self, *args)

    def insert(self, *args):
        return _medequivalence.MEDCHAR_insert(self, *args)

    def reserve(self, n):
        return _medequivalence.MEDCHAR_reserve(self, n)

    def capacity(self):
        return _medequivalence.MEDCHAR_capacity(self)

    def __iadd__(self, value):
        return _medequivalence.MEDCHAR___iadd__(self, value)

    def __add__(self, value):
        return _medequivalence.MEDCHAR___add__(self, value)

    def __isub__(self, value):
        return _medequivalence.MEDCHAR___isub__(self, value)

    def __sub__(self, value):
        return _medequivalence.MEDCHAR___sub__(self, value)

    def __imul__(self, value):
        return _medequivalence.MEDCHAR___imul__(self, value)

    def __mul__(self, value):
        return _medequivalence.MEDCHAR___mul__(self, value)

    def __itruediv__(self, *args):
        return _medequivalence.MEDCHAR___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medequivalence.MEDCHAR___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medequivalence.MEDCHAR___le__(self, value)

    def __lt__(self, value):
        return _medequivalence.MEDCHAR___lt__(self, value)

    def __gt__(self, value):
        return _medequivalence.MEDCHAR___gt__(self, value)

    def __ge__(self, value):
        return _medequivalence.MEDCHAR___ge__(self, value)

    def __eq__(self, value):
        return _medequivalence.MEDCHAR___eq__(self, value)

    def __ne__(self, value):
        return _medequivalence.MEDCHAR___ne__(self, value)
    __swig_destroy__ = _medequivalence.delete_MEDCHAR

# Register MEDCHAR in _medequivalence:
_medequivalence.MEDCHAR_swigregister(MEDCHAR)

MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


def MEDequivalenceCr(fid, meshname, equivname, description):
    r"""
    MEDequivalenceCr(fid, meshname, equivname, description) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    equivname: char const *const
    description: char const *const

    """
    return _medequivalence.MEDequivalenceCr(fid, meshname, equivname, description)

def MEDequivalenceCorrespondenceWr(fid, meshname, equivname, numdt, numit, entitype, geotype, nentity, correspondence):
    r"""
    MEDequivalenceCorrespondenceWr(fid, meshname, equivname, numdt, numit, entitype, geotype, nentity, correspondence) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    equivname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    nentity: med_int const
    correspondence: med_int const *const

    """
    return _medequivalence.MEDequivalenceCorrespondenceWr(fid, meshname, equivname, numdt, numit, entitype, geotype, nentity, correspondence)

def MEDequivalenceCorrespondenceRd(fid, meshname, equivname, numdt, numit, entitype, geotype, correspondence):
    r"""
    MEDequivalenceCorrespondenceRd(fid, meshname, equivname, numdt, numit, entitype, geotype, correspondence) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    equivname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    correspondence: med_int *const

    """
    return _medequivalence.MEDequivalenceCorrespondenceRd(fid, meshname, equivname, numdt, numit, entitype, geotype, correspondence)

def MEDnEquivalence(fid, meshname):
    r"""
    MEDnEquivalence(fid, meshname) -> med_int

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medequivalence.MEDnEquivalence(fid, meshname)

def MEDequivalenceInfo(fid, meshname, equivit):
    r"""
    MEDequivalenceInfo(fid, meshname, equivit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    equivit: int const

    """
    return _medequivalence.MEDequivalenceInfo(fid, meshname, equivit)

def MEDequivalenceComputingStepInfo(fid, meshname, equivname, csit):
    r"""
    MEDequivalenceComputingStepInfo(fid, meshname, equivname, csit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    equivname: char const *const
    csit: int const

    """
    return _medequivalence.MEDequivalenceComputingStepInfo(fid, meshname, equivname, csit)

def MEDequivalenceCorrespondenceSizeInfo(fid, meshname, equivname, numdt, numit, corit, geotype):
    r"""
    MEDequivalenceCorrespondenceSizeInfo(fid, meshname, equivname, numdt, numit, corit, geotype) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    equivname: char const *const
    numdt: med_int const
    numit: med_int const
    corit: int const
    geotype: med_geometry_type *const

    """
    return _medequivalence.MEDequivalenceCorrespondenceSizeInfo(fid, meshname, equivname, numdt, numit, corit, geotype)

def MEDequivalenceCorrespondenceSize(fid, meshname, equivname, numdt, numit, entitype, geotype):
    r"""
    MEDequivalenceCorrespondenceSize(fid, meshname, equivname, numdt, numit, entitype, geotype) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    equivname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const

    """
    return _medequivalence.MEDequivalenceCorrespondenceSize(fid, meshname, equivname, numdt, numit, entitype, geotype)

